param(
[string]$ACTIVITY,
[string]$IP,
[string]$PASSWORD
)

Write-Host "Intel(R) Dynamic Platform Thermal Framework UI Installer"

if(!$IP -or !$PASSWORD -or !$ACTIVITY)
{
	Write-Host "To use this installer script without entering each values via prompt:"
	Write-Host "setup-iot.ps1 [Install | Uninstall] [IP address] [Password]"
	Write-Host ""
	
	$ACTIVITY = Read-Host -Prompt 'Please input "Install" or "uninstall"'
	$IP = Read-Host -Prompt 'Input the IOT SUT IP address'
	$PASSWORD = Read-Host -Prompt 'Input the IOT SUT Admin password'
}
else
{
	Set-ExecutionPolicy RemoteSigned
}

net start winrm
Set-Item WSMan:\localhost\Client\TrustedHosts -value $IP 

$InputPassword = convertto-securestring -AsPlainText -Force -String $PASSWORD
$Cred = new-object System.Management.Automation.PSCredential ("$IP\Administrator",$InputPassword)
$RemoteSessionID = New-PSSession -ComputerName $IP -Credential $Cred

$UIFolder = "\\$IP\C$\Program Files\Intel\Intel(R) Dynamic Platform and Thermal Framework\ui"
$DVFolder = "\\$IP\C$\Windows\ServiceProfiles\LocalService\AppData\Local\Intel\DPTF"

if($ACTIVITY -like "install")
{
	#creating folder path if not present
	if(!(Test-Path -Path $DVFolder)) {New-Item $DVFolder -Type Directory}
	if(!(Test-Path -Path $UIFolder)) {New-Item $UIFolder -Type Directory}

	#copying dependencies
	Copy-Item ui\* -destination $UIFolder -Force
	Copy-Item dv\* -Destination $DVFolder -Force
	
	Write-Host "DPTF UI Installation completed."
	Write-Host -nonewline "Please restart your system." -foregroundcolor red 
}
ElseIf($ACTIVITY -like "uninstall")
{
	#delete UI folder if present
	if(Test-Path -Path $UIFolder) {Remove-Item $UIFolder -Recurse -Force}

	#delete other file(s)
	Remove-Item $DVFolder\startup.dv -Force
	
	Write-Host "DPTF UI Uninstallation completed."
	Write-Host -nonewline "Please restart your system." -foregroundcolor red 
}
Else
{
	Write-Host "Invalid command"
}

